@@ -267,7 +267,7 @@ role_series_element_allocate (GogObject *series)
 	GogObject *gse;
 
 	if (type == 0)
-		type = GOG_TYPE_SERIES_ELEMENT;
+		return NULL;
 
 	gse = g_object_new (type, NULL);
 	if (gse != NULL)
@@ -605,6 +605,13 @@ gog_series_update (GogObject *obj)
 	series->needs_recalc = FALSE;
 }
 
+static void
+gog_series_child_added (GogObject *parent, GogObject *child)
+{
+	if (GOG_IS_TREND_LINE (child))
+		gog_plot_request_cardinality_update (GOG_SERIES (parent)->plot);
+}
+
 static void
 gog_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
@@ -658,6 +665,8 @@ gog_series_class_init (GogSeriesClass *klass)
 	gog_klass->populate_editor	= gog_series_populate_editor;
 #endif
 	gog_klass->update		= gog_series_update;
+	gog_klass->child_added		= gog_series_child_added;
+	gog_klass->child_removed	= gog_series_child_added;
 	style_klass->init_style 	= gog_series_init_style;
 	/* series do not have views, so just forward signals from the plot */
 	gog_klass->use_parent_as_proxy  = TRUE;
@@ -937,7 +946,7 @@ gog_series_get_name (GogSeries const *series)
  * gog_series_set_name :
  * @series : a #GogSeries
  * @name_src : a #GODataScalar
- * @err : a #Gerror
+ * @err : a #GError
  *
  * Absorbs a ref to @name_src.
  *
@@ -953,7 +962,7 @@ gog_series_set_name (GogSeries *series, GODataScalar *name_src, GError **err)
  * @series : #GogSeries
  * @dim_i : Which dimension
  * @val   : #GOData
- * @err : optional #Gerror pointer
+ * @err : optional #GError pointer
  *
  * Absorbs a ref to @val
  **/
